--
-- AttacherVehicleHasControlPanel
-- Specialization for AttacherVehicleHasControlPanel functionality
--
-- Modschmiede / LS-Modsource
-- @author  Manuel Leithner
-- @modified by  Tobias F. (John Deere 6930, 1. LS-Modschmiede)
-- @date  02/10/09

AttacherVehicleHasControlPanel = {};

function AttacherVehicleHasControlPanel.prerequisitesPresent(specializations)
    return true;
end;

function AttacherVehicleHasControlPanel:load(xmlFile)

	local controlPanel = getXMLString(xmlFile, "vehicle.controlPanel#file");
	if controlPanel ~= nil then
		controlPanel = Utils.getFilename(controlPanel, self.baseDirectory);
		self.controlPanel = controlPanel;
	else
		print("No controlpanel path available");
	end;
	
	self.controlAttacherVehicle = nil;
end;

function AttacherVehicleHasControlPanel:delete()
end;

function AttacherVehicleHasControlPanel:mouseEvent(posX, posY, isDown, isUp, button)
end;

function AttacherVehicleHasControlPanel:keyEvent(unicode, sym, modifier, isDown)
end;

function AttacherVehicleHasControlPanel:update(dt)
	if self.attacherVehicle ~= nil then
		if self.attacherVehicle.attacherVehicle == nil then
			if self.controlAttacherVehicle ~= nil then
				local controlPanel = self.controlAttacherVehicle.controlPanel;
				
				if controlPanel ~= nil then
					if controlPanel.implement == self then
						if controlPanel.loaded ~= nil then
							-- delete controlPanel
							delete(controlPanel.loaded);
							controlPanel.loaded = nil;
							controlPanel.implement = nil;
						end;
					end;
				end;
				self.controlAttacherVehicle = nil;
			end;	
		else
			if self.controlAttacherVehicle == nil then
				local panel = self.attacherVehicle.attacherVehicle.controlPanel;
				if panel ~= nil then
					if panel.loaded == nil then
						-- load,link i3d-File
						local i3dPanel = loadI3DFile(self.controlPanel);
						if i3dPanel ~= 0 then
							link(panel.node, i3dPanel);
							panel.loaded = i3dPanel;
							panel.implement = self;
							self.controlAttacherVehicle = self.attacherVehicle.attacherVehicle;
						end;
					end;	
				end;
			end;
		end;
	end;
end;

function AttacherVehicleHasControlPanel:draw()
end;

function AttacherVehicleHasControlPanel:onAttach(attacherVehicle)
	if attacherVehicle.attacherVehicle ~=nil then
		local panel = attacherVehicle.attacherVehicle.controlPanel;
		if panel ~= nil then
			if panel.loaded == nil then
				-- load,link i3d-File
				local i3dPanel = loadI3DFile(self.controlPanel);
				if i3dPanel ~= 0 then
					link(panel.node, i3dPanel);
					panel.loaded = i3dPanel;
					panel.implement = self;
					self.controlAttacherVehicle = attacherVehicle.attacherVehicle;
				end;
			end;	
		end;
	end;
end;


function AttacherVehicleHasControlPanel:onDetach()

	if self.controlAttacherVehicle ~= nil then
		local controlPanel = self.controlAttacherVehicle.controlPanel;
		
		if controlPanel ~= nil then
			if controlPanel.implement == self then
				if controlPanel.loaded ~= nil then
					-- delete controlPanel
					delete(controlPanel.loaded);
					controlPanel.loaded = nil;
					controlPanel.implement = nil;
				end;
			end;
		end;
		
		self.controlAttacherVehicle = nil;
	end;

end;
